function vec = computeBlockVector(blockDir, blockMagn, cellWidth, cellHeight)
	[hei, wid] = size(blockDir);

	numCellsWidth = wid / cellWidth;
	numCellsHeight = hei / cellHeight;
	
	% We have a histogram for each cell, where each histogram has 9 bins
	vec = zeros(1, numCellsWidth * numCellsHeight * 9);
	vecStart = 0;
	for i = 1:numCellsWidth
		cellWidStart = (i - 1) * cellWidth + 1;
		for j = 1:numCellsHeight
			cellHeiStart = (j - 1) * cellHeight + 1;
			% Taking the cell's sub-matrices of direction and of magnitude
			cellDir = blockDir(cellHeiStart:cellHeiStart + cellHeight - 1, cellWidStart:cellWidStart + cellWidth - 1);
			cellMagn = blockMagn(cellHeiStart:cellHeiStart + cellHeight - 1, cellWidStart:cellWidStart + cellWidth - 1);
			
			% Assigning the values to the main vector, in the current cell's allocated 9 indices
			% The values are actually: for bin "x" - the sum of magnitudes for pixels with direction "x"
			for b = 1:9
				vec(vecStart + b) = sum(cellMagn(cellDir == b));
			end
			
			vecStart = vecStart + 9;
		end
	end
	% Normalizing vector - dividing each v[i] in:  sqrt(v[1]^2 + v[2]^2 + ... + v[n]^2 + epsilon^2)
	vecPow = vec .^ 2;
	epsilon = 1;
	n2 = sqrt(sum(vecPow) + (epsilon ^ 2));
	vec = vec / n2;
end
